__AUTHOR__ = "Dipankar Pal"
__EMAIL__ = "dipankarpal5050@gmail.com"
__WEBSITE__ = "deep5050.github.io"

# def get_version():
#     return __VERSION__

# if __name__ == "__main__":
#     get_version()
