"""
    Version of the current program, ( in development mode it needs to be updated in every realease)
"""
__VERSION__ = "2.1.2"


def get_version():
    """ get the version number as string """
    return __VERSION__


if __name__ == "__main__":
    get_version()
